@@ -4,6 +4,7 @@ import io
 import json
 import os
 import pathlib
+import subprocess
 import typing as t
 
 import pytest
@@ -12,7 +13,7 @@ from pytest_mock import MockerFixture
 
 import libtmux
 from libtmux.common import has_lt_version
-from libtmux.exc import LibTmuxException
+from libtmux.server import Server
 from libtmux.session import Session
 from tmuxp import cli, exc
 from tmuxp.cli.import_config import get_teamocil_dir, get_tmuxinator_dir
@@ -35,8 +36,6 @@ from .fixtures import utils as test_utils
 if t.TYPE_CHECKING:
     import _pytest.capture
 
-    from libtmux.server import Server
-
 
 def test_creates_config_dir_not_exists(tmp_path: pathlib.Path) -> None:
     """cli.startup() creates config dir if not exists."""
@@ -80,6 +79,28 @@ def test_load_workspace(server: "Server", monkeypatch: pytest.MonkeyPatch) -> No
     assert session.name == "sample workspace"
 
 
+def test_load_workspace_passes_tmux_config(
+    server: "Server", monkeypatch: pytest.MonkeyPatch
+) -> None:
+    # this is an implementation test. Since this testsuite may be ran within
+    # a tmux session by the developer himself, delete the TMUX variable
+    # temporarily.
+    monkeypatch.delenv("TMUX", raising=False)
+    session_file = FIXTURE_PATH / "workspace/builder" / "two_pane.yaml"
+
+    # open it detached
+    session = load_workspace(
+        session_file,
+        socket_name=server.socket_name,
+        tmux_config_file=str(FIXTURE_PATH / "tmux" / "tmux.conf"),
+        detached=True,
+    )
+
+    assert isinstance(session, Session)
+    assert isinstance(session.server, Server)
+    assert session.server.config_file == str(FIXTURE_PATH / "tmux" / "tmux.conf")
+
+
 def test_load_workspace_named_session(
     server: "Server", monkeypatch: pytest.MonkeyPatch
 ) -> None:
@@ -174,7 +195,7 @@ windows:
     assert session.name == "samplesimple"
 
     assert pane is not None
-    assert pane.current_path == str(realtemp)
+    assert pane.pane_current_path == str(realtemp)
 
 
 if t.TYPE_CHECKING:
@@ -563,7 +584,7 @@ def test_shell(
             [],
             {},
             {},
-            LibTmuxException,
+            subprocess.CalledProcessError,
             r".*DoesNotExist.*",
         ),
         (
@@ -601,7 +622,9 @@ def test_shell_target_missing(
     inputs: t.List[t.Any],
     env: t.Dict[t.Any, t.Any],
     template_ctx: t.Dict[str, str],
-    exception: t.Union[t.Type[exc.TmuxpException], t.Type[LibTmuxException]],
+    exception: t.Union[
+        t.Type[exc.TmuxpException], t.Type[subprocess.CalledProcessError]
+    ],
     message: str,
     socket_name: str,
     server: "Server",
@@ -955,10 +978,9 @@ def test_freeze(
     server.new_session(session_name="myfrozensession")
 
     # Assign an active pane to the session
-    second_session = server.list_sessions()[1]
-    first_pane_on_second_session_id = second_session.list_windows()[0].list_panes()[0][
-        "pane_id"
-    ]
+    second_session = server.sessions[1]
+    first_pane_on_second_session_id = second_session.windows[0].panes[0].pane_id
+    assert first_pane_on_second_session_id
     monkeypatch.setenv("TMUX_PANE", first_pane_on_second_session_id)
 
     monkeypatch.chdir(tmp_path)
@@ -1125,7 +1147,9 @@ def test_ls_cli(
 
 
 def test_load_plugins(monkeypatch_plugin_test_packages: None) -> None:
-    from tmuxp_test_plugin_bwb.plugin import PluginBeforeWorkspaceBuilder
+    from tmuxp_test_plugin_bwb.plugin import (  # type: ignore
+        PluginBeforeWorkspaceBuilder,
+    )
 
     plugins_config = test_utils.read_workspace_file("workspace/builder/plugin_bwb.yaml")
 
@@ -1339,17 +1363,18 @@ def test_load_append_windows_to_current_session(
     builder = WorkspaceBuilder(sconf=sconfig, server=server)
     builder.build()
 
-    assert len(server.list_sessions()) == 1
-    assert len(server._list_windows()) == 3
+    assert len(server.sessions) == 1
+    assert len(server.windows) == 3
 
     # Assign an active pane to the session
-    monkeypatch.setenv("TMUX_PANE", server._list_panes()[0]["pane_id"])
+    assert server.panes[0].pane_id
+    monkeypatch.setenv("TMUX_PANE", server.panes[0].pane_id)
 
     builder = WorkspaceBuilder(sconf=sconfig, server=server)
     _load_append_windows_to_current_session(builder)
 
-    assert len(server.list_sessions()) == 1
-    assert len(server._list_windows()) == 6
+    assert len(server.sessions) == 1
+    assert len(server.windows) == 6
 
 
 def test_debug_info_cli(
